export const BOILERPLATE_OPTIONS = {
    connector: "Connector",
    ui: "Integration UI",
    build: "Build Event Handler",
    edgeFunctions: "Edge Function Injection",
    functions: "Functions Injection",
};
export const example = ({ boilerplate, addEdgeFunctionConfig, }) => {
    let code = `import { NetlifyIntegration } from "@netlify/sdk";

const integration = new NetlifyIntegration();
`;
    if (boilerplate.includes(BOILERPLATE_OPTIONS.connector)) {
        code += `const connector = integration.addConnector({
  typePrefix: "Example",
});

/**
 * Define your content models here.
 * https://developers.netlify.com/sdk/api-reference/classes/netlifyconnector/#model
 */
connector.model(async ({ define }) => {
  define.nodeModel({
    name: "User",
    fields: {
      name: {
        type: "String",
        required: true,
      },
      posts: {
        type: "Post",
        list: true,
      },
    },
  });

  define.document({
    name: "Post",
    fields: {
      title: {
        type: "String",
        required: true,
      },
      blocks: {
        list: true,
        required: true,
        type: define.object({
          name: "Blocks",
          fields: {
            title: {
              type: "String",
            },
            content: {
              type: "String",
            },
          },
        }),
      },
    },
  });
});

/**
 * Fetch and store data from your API here.
 * https://developers.netlify.com/sdk/api-reference/classes/netlifyconnector/#sync
 */
connector.sync(({ models, isInitialSync }) => {
  switch (true) {
    case isInitialSync: {
      models.User.insert({
        id: "1",
        name: "Annie",
        posts: [
          {
            id: "1",
            __typename: "Post",
          },
        ],
      });
      models.Post.insert({
        id: "1",
        title: "Hello World",
        blocks: [
          {
            title: "Example block title",
            content: "You can create complex content models",
          },
        ],
      });
      break
    }
    case !isInitialSync: {
      models.User.insert({
        id: "1", // overwrites the existing User node with this ID
        name: "Annie",
        posts: [
          {
            id: "1",
            __typename: "Post",
          },
        ],
      });
      models.Post.insert({
        id: "2", // creates a new Post since this ID doesn't exist yet
        title: "Writing lots of posts these days",
        blocks: [
          {
            title: "Page section",
            content: "what up",
          },
        ],
      });
      break
    }
  }
});
`;
    }
    if (boilerplate.includes(BOILERPLATE_OPTIONS.build)) {
        code += `
integration.addBuildEventHandler("onPreBuild", () => {
  console.log("Hello there.");
});
  `;
    }
    if (addEdgeFunctionConfig ||
        boilerplate.includes(BOILERPLATE_OPTIONS.edgeFunctions)) {
        code += `
integration.addEdgeFunctions("./src/edge-functions", {
  prefix: "ef_prefix",
});
`;
    }
    if (boilerplate.includes(BOILERPLATE_OPTIONS.functions)) {
        code += `
integration.addFunctions("./src/functions", {
  prefix: "my_unique_prefix",
});
`;
    }
    code += `
export { integration };

`;
    return code;
};
export const createBasicIntegrationUI = (friendlyName) => `import { NetlifyIntegrationUI } from "@netlify/sdk";

const integrationUI = new NetlifyIntegrationUI("${friendlyName}");

const surface = integrationUI.addSurface("integrations-settings");

const route = surface.addRoute("/");

route.addText({
    value: "Welcome to the ${friendlyName} integration UI. This is where you can create your own custom UI for your integration, which will be displayed in the Netlify UI."
});

export { integrationUI };

`;
export const GITIGNORE = `
.ntli
node_modules
.cache
dev-model.gql
`;
// TODO: Do we need to add more info to a default details file?
export const createDetails = (integrationName) => `
View and install the ${integrationName} integration.
`;
export const createReadme = (component) => `
# Netlify Integration

This integration is created using the [Netlify SDK](https://sdk.netlify.com/get-started/introduction/). It is a boilerplate for creating a new integration.

## Scripts

These are some common scripts you will use when developing your integration. If you want to know what else is possible, [check out the documentation](https://sdk.netlify.com/netlify-sdk-utility-tools-reference/).

### Build

This builds the integration into a \`.ntli\` folder. This is the folder that Netlify uses to run the integration.

\`\`\`bash
npm run build
\`\`\`
${component === "connector"
    ? `### Dev

This bundles your integration code and starts a local GraphQL server for any Connectors you have defined. This is useful for testing your integration locally.

\`\`\`bash
npm run dev
\`\`\`
`
    : ""}
${component === "ui"
    ? `### Preview

This bundles your integration code and starts a preview server. This is useful for previewing your integration UI locally.

\`\`\`bash
npm run preview
\`\`\``
    : ""}
### Deploy

Are you ready to deploy your integration? Check our documentation on publishing your ntegration as a [private integration](https://sdk.netlify.com/publish/private-integrations/) or [partner integration](https://sdk.netlify.com/publish/partner-integrations/).
`;
export const testEdgeFunction = `// Documentation: https://sdk.netlify.com

export default () => new Response('Hello, world!');

export const config = {
  path: '/test',
};

`;
export const testFunction = `// Documentation: https://sdk.netlify.com

export default async () => {
  return new Response("Hello, world!");
};

`;
//# sourceMappingURL=constants.js.map